==> derry-0.1.2.tar.gz: lib/src/commands/run.dart <==
part of derry;

/// the `derry run` command
class RunCommmand extends Command {
  bool get alias => false;

  @override
  String get name => 'run';

  @override
  String get description => 'find the script definition and execute it';

  RunCommmand() {
    super.argParser.addFlag(
          'silent',
          abbr: 's',
          help: 'determine whether to show outputs or not',
          defaultsTo: false,
          negatable: false,
        );
  }

  Map<String, dynamic> parseExtras(List<String> args) {
    final flag = args.contains('--');

    if (flag) {
      final start = args.indexOf('--');
      return <String, List>{
        'args': args.sublist(0, start).toList(),
        'extra': args.sublist(start + 1).toList(),
      };
    } else {
      return <String, List>{
        'args': args,
        'extra': [],
      };
    }
  }

  @override
  Future<void> run() async {
    final parsed = parseExtras(super.argResults.arguments);
    final args = super.argParser.parse(parsed['args']).rest;
    final extra = parsed['extra'].join(' ');
    final silent = super.argResults['silent'];

    if (args.isEmpty && !alias) {
      print(super.usage);
    } else {
      final arg =
          alias ? '$name ${args.join(' ')}'.trim() : args.join(' ').trim();

      final info = await loadInfo();
      final definitions = await loadDefinitions();
      final infoLine = '> ${info.name}@${info.version} $arg';

      execute(
        definitions,
        arg,
        extra: extra,
        silent: silent,
        infoLine: infoLine,
      );
    }
  }
}

==> derry-1.0.3.tar.gz: lib/src/commands/run.dart <==
part of derry;

/// the `derry run` command
class RunCommmand extends Command {
  bool get alias => false;

  @override
  String get name => 'run';

  @override
  String get description => 'find the script definition and execute it';

  RunCommmand() {
    super.argParser.addFlag(
          'silent',
          abbr: 's',
          help: 'determine whether to show outputs or not',
          negatable: false,
        );
  }

  Map<String, dynamic> parseExtras(List<String> args) {
    final flag = args.contains('--');

    if (flag) {
      final start = args.indexOf('--');
      return <String, List>{
        'args': args.sublist(0, start).toList(),
        'extra': args.sublist(start + 1).toList(),
      };
    } else {
      return <String, List>{
        'args': args,
        'extra': [],
      };
    }
  }

  @override
  Future<void> run() async {
    final parsed = parseExtras(super.argResults.arguments);
    final args = super.argParser.parse(parsed['args'] as Iterable<String>).rest;
    final extra = (parsed['extra'] as List).join(' ');
    final silent = super.argResults['silent'] as bool;

    if (args.isEmpty && !alias) {
      stdout.writeln(super.usage);
    } else {
      final arg =
          alias ? '$name ${args.join(' ')}'.trim() : args.join(' ').trim();

      final info = await loadInfo();
      final definitions = await loadDefinitions();
      final infoLine = '> ${info.name}@${info.version} $arg';

      execute(
        definitions,
        arg,
        extra: extra,
        silent: silent,
        infoLine: infoLine,
      );
    }
  }
}
